# -*- coding: utf-8 -*-
from openerp.osv import fields, osv
import openerp.addons.decimal_precision as dp
from datetime import date


class Theme(osv.osv):
    _name = 'bikecoop.partner.theme'
    _description = 'Themes that could be related to a partner'

    _columns = {
        'code': fields.char('Code', size=8, help='Code of the occupation'),
        'name': fields.char('Name', size=128, help='Name of the job or studies', required=True, translate=True),
        'domain': fields.selection([('gender', 'Gender'), ('occupation', 'Occupation'), ('volunteer', 'Volunteer')], 'Domain', required=True, size=24),
        'active': fields.boolean('Active', help='If check, this object is always available'),
    }

    _defaults = {
        'active': lambda *a: 1,
    }

Theme()


class Partner(osv.osv):
    _inherit = 'res.partner'

    _columns = {
        'nationality_id': fields.many2one('res.country', 'Nationality', help='Partner\'s nationality if he is a person'),
        'year': fields.integer('Year of birth', help='This partner year of birth'),
        'occupation_id': fields.many2one('bikecoop.partner.theme', 'Occupation', help='Main occupation of this partner'),
        'volunteer_ids': fields.many2many('bikecoop.partner.theme', 'res_partner_bikecoop_theme_rel', 'partner_id', 'theme_id', 'Want to be volunteer?', help='What kind of volunteer activities you want to do with us?'),
        'gender_id': fields.many2one('bikecoop.partner.theme', 'Gender'),
    }

    def _check_year(self, cr, uid, ids, context=None):
        obj = self.browse(cr, uid, ids[0], context=context)
        if obj.year:
            if obj.year < 1900 or obj.year > date.today().year:
                return False
        return True

    _constraints = [
        (_check_year, 'Error: this year is not valid.', ['year']),
    ]
Partner()


class product_template(osv.osv):
    _inherit = 'product.template'

    _columns = {
        'standard_price': fields.float('Cost', digits_compute=dp.get_precision('Product Price'), help="Cost price of the product used for standard stock valuation in accounting and used as a base price on purchase orders.", groups="base.group_user,point_of_sale.group_pos_user"),
    }

product_template()


# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
